@@ -7,17 +7,17 @@ $parent_file = 'options-general.php';
 include('admin-header.php');
 ?>
 
-<div class="wrap"> 
-<h2><?php _e('Writing Options') ?></h2> 
-<form method="post" action="options.php"> 
+<div class="wrap">
+<h2><?php _e('Writing Options') ?></h2>
+<form method="post" action="options.php">
 <?php wp_nonce_field('update-options') ?>
 <p class="submit"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
-<table width="100%" cellspacing="2" cellpadding="5" class="optiontable editform"> 
-<tr valign="top"> 
-<th width="33%" scope="row"> <?php _e('Size of the post box:') ?></th> 
-<td><input name="default_post_edit_rows" type="text" id="default_post_edit_rows" value="<?php form_option('default_post_edit_rows'); ?>" size="2" style="width: 1.5em; " /> 
-<?php _e('lines') ?></td> 
-</tr> 
+<table width="100%" cellspacing="2" cellpadding="5" class="optiontable editform">
+<tr valign="top">
+<th width="33%" scope="row"> <?php _e('Size of the post box:') ?></th>
+<td><input name="default_post_edit_rows" type="text" id="default_post_edit_rows" value="<?php form_option('default_post_edit_rows'); ?>" size="2" style="width: 1.5em; " />
+<?php _e('lines') ?></td>
+</tr>
 <tr valign="top">
 <th scope="row"><?php _e('Formatting:') ?></th>
 <td>
@@ -31,11 +31,12 @@ include('admin-header.php');
 <th scope="row"><?php _e('Default post category:') ?></th>
 <td><select name="default_category" id="default_category">
 <?php
-$categories = $wpdb->get_results("SELECT * FROM $wpdb->categories ORDER BY cat_name");
+$categories = get_categories('get=all');
 foreach ($categories as $category) :
-if ($category->cat_ID == get_option('default_category')) $selected = " selected='selected'";
+$category = sanitize_category($category);
+if ($category->term_id == get_option('default_category')) $selected = " selected='selected'";
 else $selected = '';
-echo "\n\t<option value='$category->cat_ID' $selected>$category->cat_name</option>";
+echo "\n\t<option value='$category->term_id' $selected>$category->name</option>";
 endforeach;
 ?>
 </select></td>
@@ -44,10 +45,12 @@ endforeach;
 <th scope="row"><?php _e('Default link category:') ?></th>
 <td><select name="default_link_category" id="default_link_category">
 <?php
-foreach ($categories as $category) :
-if ($category->cat_ID == get_option('default_link_category')) $selected = " selected='selected'";
+$link_categories = get_terms('link_category', 'get=all');
+foreach ($link_categories as $category) :
+$category = sanitize_term($category, 'link_category');
+if ($category->term_id == get_option('default_link_category')) $selected = " selected='selected'";
 else $selected = '';
-echo "\n\t<option value='$category->cat_ID' $selected>$category->cat_name</option>";
+echo "\n\t<option value='$category->term_id' $selected>$category->name</option>";
 endforeach;
 ?>
 </select></td>
@@ -82,6 +85,7 @@ endforeach;
 <?php
 //Alreay have $categories from default_category
 foreach ($categories as $category) :
+$category = sanitize_category($category);
 if ($category->cat_ID == get_option('default_email_category')) $selected = " selected='selected'";
 else $selected = '';
 echo "\n\t<option value='$category->cat_ID' $selected>$category->cat_name</option>";
